@@ -20,7 +20,7 @@ use libflate::gzip::{
 	Encoder,
 };
 
-use crate::error::CompressionError;
+use crate::error::{ CacheError, CompressionError };
 
 #[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug)]
 pub enum Compression {
@@ -29,8 +29,87 @@ pub enum Compression {
 	Gzip,
 }
 
-/// Encodes a buffer, with the selected `Compression` format. Revision is an optional argument
-/// that encodes the version of this buffer into it, if no revision should be encoded
+/// Decodes a cache buffer with some additional data.
+/// 
+/// This struct can be useful if you need more details then just the decoded data.
+/// 
+/// # Examples
+/// 
+/// `TryFrom<&[u8]> -> DecodedBuffer`:  
+/// ```
+/// # use rscache::{ Cache, store::MemoryStore };
+/// # use rscache::codec::Compression;
+/// use rscache::codec::DecodedBuffer;
+/// use std::convert::TryFrom;
+/// 
+/// # fn main() -> rscache::Result<()> {
+/// # let path = "./data/osrs_cache";
+/// # let cache: Cache<MemoryStore> = Cache::new(path)?;
+/// let buffer = cache.read(2, 10)?;
+/// let decoded = DecodedBuffer::try_from(buffer.as_slice())?;
+/// 
+/// assert_eq!(decoded.compression, Compression::Bzip2);
+/// assert_eq!(decoded.len, 260526);
+/// assert_eq!(decoded.version, Some(12609));
+/// # Ok(())
+/// # }
+/// ```
+/// 
+/// Getting the inner buffer:
+/// This conversion is free.
+/// ```
+/// # use rscache::{ Cache, store::MemoryStore };
+/// # use rscache::codec::Compression;
+/// # use rscache::codec::DecodedBuffer;
+/// # use std::convert::TryFrom;
+/// # fn main() -> rscache::Result<()> {
+/// # let path = "./data/osrs_cache";
+/// # let cache: Cache<MemoryStore> = Cache::new(path)?;
+/// let buffer = cache.read(2, 10)?;
+/// let decoded = DecodedBuffer::try_from(buffer.as_slice())?;
+/// 
+/// let inner_buffer: Vec<u8> = decoded.into_vec();
+/// # Ok(())
+/// # }
+/// ```
+#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
+pub struct DecodedBuffer {
+	pub compression: Compression,
+	pub len: usize,
+	pub version: Option<i16>,
+	buffer: Vec<u8>
+}
+
+impl DecodedBuffer {
+	/// Free conversion from `DecodedBuffer` into `Vec<u8>`.
+	/// 
+	/// # Examples
+	/// 
+	/// ```
+	/// # use rscache::{ Cache, store::MemoryStore };
+	/// # use rscache::codec::Compression;
+	/// # use rscache::codec::DecodedBuffer;
+	/// # use std::convert::TryFrom;
+	/// # fn main() -> rscache::Result<()> {
+	/// # let path = "./data/osrs_cache";
+	/// # let cache: Cache<MemoryStore> = Cache::new(path)?;
+	/// let buffer = cache.read(2, 10)?;
+	/// let decoded = DecodedBuffer::try_from(buffer.as_slice())?;
+	/// 
+	/// let inner_buffer: Vec<u8> = decoded.into_vec();
+	/// # Ok(())
+	/// # }
+	/// ```
+	// False positive, issue already open but not being worked on atm.
+	#[allow(clippy::missing_const_for_fn)]
+	#[inline]
+	pub fn into_vec(self) -> Vec<u8> {
+		self.buffer
+	}
+}
+
+/// Encodes a buffer, with the selected `Compression` format. version is an optional argument
+/// that encodes the version of this buffer into it, if no version should be encoded
 /// pass None.
 /// 
 /// The following process takes place when encoding:
@@ -40,7 +119,7 @@ pub enum Compression {
 /// 4. Push the length (u32) into the buffer of the compressed data from step 1.
 /// 5. If a compression type was selected (and not `Compression::None`) insert the uncompressed length as u32.
 /// 6. Extend the buffer with the compressed data.
-/// 7. Add the `revision` as i16 if present.
+/// 7. Add the `version` as i16 if present.
 /// 8. Encode complete.
 /// 
 /// Supported compression types:
@@ -69,7 +148,7 @@ pub enum Compression {
 /// # }
 /// ```
 #[inline]
-pub fn encode(compression: Compression, data: &[u8], revision: Option<i16>) -> crate::Result<Vec<u8>> {
+pub fn encode(compression: Compression, data: &[u8], version: Option<i16>) -> crate::Result<Vec<u8>> {
 	let compressed_data = match compression {
 		Compression::None => data.to_owned(),
 		Compression::Bzip2 => compress_bzip2(data)?,
@@ -86,8 +165,8 @@ pub fn encode(compression: Compression, data: &[u8], revision: Option<i16>) -> c
 
 	buffer.extend(compressed_data);
 
-	if let Some(revision) = revision {
-		buffer.extend(&i16::to_be_bytes(revision));
+	if let Some(version) = version {
+		buffer.extend(&i16::to_be_bytes(version));
 	}
 
 	Ok(buffer)
@@ -120,17 +199,7 @@ pub fn encode(compression: Compression, data: &[u8], revision: Option<i16>) -> c
 /// ```
 #[inline]
 pub fn decode(buffer: &[u8]) -> crate::Result<Vec<u8>> {
-	let (buffer, compression) = be_u8(buffer)?;
-	let compression = Compression::try_from(compression)?;
-
-	let (buffer, len) = be_u32(buffer)?;
-	let (_revision, buffer) = match compression {
-		Compression::None => decompress_none(buffer, len as usize)?,
-		Compression::Bzip2 => decompress_bzip2(buffer, len as usize)?,
-		Compression::Gzip => decompress_gzip(buffer, len as usize)?,
-	};
-
-	Ok(buffer)
+	Ok(DecodedBuffer::try_from(buffer)?.into_vec())
 }
 
 fn compress_bzip2(data: &[u8]) -> io::Result<Vec<u8>> {
@@ -150,9 +219,9 @@ fn decompress_none(buffer: &[u8], len: usize) -> crate::Result<(Option<i16>, Vec
 	let mut compressed_data = vec![0; len];
 	compressed_data.copy_from_slice(buffer);
 
-	let (_, revision) = cond(buffer.len() - len >= 2, be_i16)(buffer)?;
+	let (_, version) = cond(buffer.len() - len >= 2, be_i16)(buffer)?;
 
-	Ok((revision, compressed_data))
+	Ok((version, compressed_data))
 }
 
 fn decompress_bzip2(buffer: &[u8], len: usize) -> crate::Result<(Option<i16>, Vec<u8>)> {
@@ -161,13 +230,13 @@ fn decompress_bzip2(buffer: &[u8], len: usize) -> crate::Result<(Option<i16>, Ve
 	compressed_data[4..len].copy_from_slice(&buffer[..len - 4]);
 	compressed_data[..4].copy_from_slice(b"BZh1");
 
-	let (_, revision) = cond(buffer.len() - len >= 2, be_i16)(buffer)?;
+	let (_, version) = cond(buffer.len() - len >= 2, be_i16)(buffer)?;
 
 	let mut decompressor = BzDecoder::new(compressed_data.as_slice());
 	let mut decompressed_data = vec![0; decompressed_len as usize];
 	decompressor.read_exact(&mut decompressed_data)?;
 
-	Ok((revision, decompressed_data))
+	Ok((version, decompressed_data))
 }
 
 fn decompress_gzip(buffer: &[u8], len: usize) -> crate::Result<(Option<i16>, Vec<u8>)> {
@@ -175,13 +244,20 @@ fn decompress_gzip(buffer: &[u8], len: usize) -> crate::Result<(Option<i16>, Vec
 	let mut compressed_data = vec![0; len - 4];
 	compressed_data.copy_from_slice(&buffer[..len - 4]);
 
-	let (_, revision) = cond(buffer.len() - len >= 2, be_i16)(buffer)?;
+	let (_, version) = cond(buffer.len() - len >= 2, be_i16)(buffer)?;
 
 	let mut decoder = Decoder::new(&compressed_data[..])?;
 	let mut decompressed_data = vec![0; decompressed_len as usize];
 	decoder.read_exact(&mut decompressed_data)?;
 
-	Ok((revision, decompressed_data))
+	Ok((version, decompressed_data))
+}
+
+impl Default for Compression {
+	#[inline]
+	fn default() -> Self {
+		Self::None
+	}
 }
 
 impl From<Compression> for u8 {
@@ -207,4 +283,29 @@ impl TryFrom<u8> for Compression {
 			_ => Err(CompressionError::Unsupported(compression))
 		}
 	}
+}
+
+impl TryFrom<&[u8]> for DecodedBuffer {
+	type Error = CacheError;
+
+	#[inline]
+	fn try_from(buffer: &[u8]) -> Result<Self, Self::Error> {
+		let (buffer, compression) = be_u8(buffer)?;
+		let compression = Compression::try_from(compression)?;
+
+		let (buffer, len) = be_u32(buffer)?;
+		let len = len as usize;
+		let (version, buffer) = match compression {
+			Compression::None => decompress_none(buffer, len)?,
+			Compression::Bzip2 => decompress_bzip2(buffer, len)?,
+			Compression::Gzip => decompress_gzip(buffer, len)?,
+		};
+
+		Ok(Self{ 
+			compression,
+			len,
+			version,
+			buffer
+		})
+	}
 }
\ No newline at end of file
