@@ -1,8 +1,8 @@
 use std::{ io::Read, fs::File };
 
 use crate::{
-	arc::Archive,
-	sec::{ Sector, SectorHeaderSize },
+	arc::ArchiveRef,
+	sec::Sector,
 	error::ParseError,
 	sec::{
 		SECTOR_SIZE,
@@ -14,6 +14,7 @@ use crate::{
 use super::Store;
 
 /// Cache inner reading from memory.
+#[derive(Debug)]
 pub struct MemoryStore {
     data: Vec<u8>
 }
@@ -28,7 +29,7 @@ impl Store for MemoryStore {
     }
 
 	#[inline]
-    fn read(&self, archive: &Archive) -> crate::Result<Vec<u8>> {
+    fn read(&self, archive: &ArchiveRef) -> crate::Result<Vec<u8>> {
 		let mut current_sector = archive.sector;
         let mut data = vec![0; archive.length];
 		let mut remaining = archive.length;
@@ -41,7 +42,7 @@ impl Store for MemoryStore {
 			if remaining >= SECTOR_DATA_SIZE {
 				let data_block = &self.data[offset..offset + SECTOR_SIZE];
 				
-				match Sector::new(data_block, &SectorHeaderSize::Normal) {
+				match Sector::from_normal_header(data_block) {
 					Ok(sector) => {
 						sector.header.validate(archive.id, chunk, archive.index_id)?;
 
@@ -58,7 +59,7 @@ impl Store for MemoryStore {
 				
 				let data_block = &self.data[offset..offset + SECTOR_HEADER_SIZE + remaining];
 				
-				match Sector::new(data_block, &SectorHeaderSize::Normal) {
+				match Sector::from_normal_header(data_block) {
 					Ok(sector) => {
 						sector.header.validate(archive.id, chunk, archive.index_id)?;
 						data[current..current + remaining].copy_from_slice(sector.data_block);
